@@ -1,14 +1,16 @@
 from ._cli import cli
+from ._misc import num_models
 from ._reader import HMMERModel, HMMERParser, ParsingError, open_hmmer
 from ._testit import test
 from ._version import __version__
 
 __all__ = [
+    "HMMERModel",
+    "HMMERParser",
+    "ParsingError",
     "__version__",
+    "cli",
+    "num_models",
     "open_hmmer",
     "test",
-    "cli",
-    "HMMERParser",
-    "HMMERModel",
-    "ParsingError",
 ]
